# Split Infinitives


Split infinitives are a specific type of misplaced modifier.

```example
Incorrect: She decided to instantly quit her job.
```


An infinitive is a verb preceded by the word to: (to write, to examine, to take,
to cooperate). When an adverb appears between to and the verb itself, we get a
split infinitive.

> **Rule To Remember**
>
> - Split infinitives are a specific type of misplaced modifier.
> - Split infinitives should be avoided in formal writing.


## Correcting Split Infinitive Problems

To correct the above sentence, instantly should appear after the verb.

```example
Correct: She decided to quit her job instantly.
```

In formal writing, it is considered bad style to split an infinitive, but in
more informal writing or in speech this has become more acceptable.

In speech, the word really is often placed between to and the verb:

```example
Non-standard: It would take incredible strength to really forget all her bad childhood memories.
```


```example
Awkward: It would take incredible strength to forget really all her bad childhood memories.
```


Placing really after forget makes the second sentence sound awkward. Really is
such a problematic word, it is best to avoid its use in writing and use a more
specific adverb.

Some degree adverbs such as completely, entirely, unduly can also create awkward
sentences when placed after the verb.

```example
Non-standard: It's hard to completely follow his reasoning.
```


```example
Awkward: It's hard to follow completely his reasoning.
```


A better choice here would be to put the adverb completely at the very end of
the sentence.

```example
Preferred: It's hard to follow his reasoning completely.
```


Sometimes avoiding the use of a split infinitive creates ambiguity. Consider the
following examples:

```example
Non-standard: The patient was told to occasionally monitor her blood sugar level.
```


```example
Correct: The patient was told occasionally to monitor her blood sugar level.
```


```example
Correct: The patient was told to monitor her blood sugar level occasionally.
```


In the second sentence, occasionally modifies the verb told and, in fact, alters
the meaning of the sentence. However, placing occasionally at the end of the
sentence creates ambiguity; does it modify the verb told now or the verb
monitor?

The best position of the modifier occasionally is right after the verb monitor
as in:

```example
Correct: The patient was told to monitor occasionally her blood sugar level.
```


In formal writing, sentences in which there is more than one element in the
infinitive phrase should be avoided:

```example
Non-standard: Our company decided to legally and rightfully seek damages for fraudulent use of the company documents.
```


Sometimes it may be necessary to rephrase the sentence to maintain the correct
form and meaning:

```example
Preferred: Our company decided to seek damages in a legal and rightful way for fraudulent use of the company documents.
```


Or

```example
Preferred: Legally and rightfully, our company decided to seek damages for fraudulent use of the company documents.
```


---

<!-- TODO: add quiz -->
